@@ -5,7 +5,7 @@ use strict;
 use DBI   1.57 ();
 use DynaLoader ();
 
-our $VERSION = '1.55_01';
+our $VERSION = '1.55_02';
 our @ISA     = 'DynaLoader';
 
 # sqlite_version cache (set in the XS bootstrap)
@@ -679,7 +679,7 @@ sub statistics_info {
             $sth->execute or return;
             while(my $row = $sth->fetchrow_hashref) {
 
-                next if defined $unique_only && $unique_only && $row->{unique};
+                next if $unique_only && !$row->{unique};
                 my $quoted_idx = $dbh->quote_identifier($row->{name});
                 for my $db (@$databases) {
                     my $quoted_db = $dbh->quote_identifier($db->{name});
@@ -977,7 +977,7 @@ are limited by the typeless nature of the SQLite database.
 =head1 SQLITE VERSION
 
 DBD::SQLite is usually compiled with a bundled SQLite library
-(SQLite version S<3.16.0> as of this release) for consistency.
+(SQLite version S<3.16.2> as of this release) for consistency.
 However, a different version of SQLite may sometimes be used for
 some reasons like security, or some new experimental features.
 
